@@ -720,7 +720,7 @@ def nlp_cluster(data_df,cluster_column,clusters,prediction_col,max_df_val,min_df
 
     data_df[prediction_col] = labels
 
-    return data_df,model,X,
+    return data_df,model,X,vectorizer
 # =======================================================
 #
 # =======================================================
